# pyAdax

Python3 library for Adax heater. 

Control Adax heaters and get measured temperatures.

[Buy me a coffee :)](http://paypal.me/dahoiv)



## Install
```
pip3 install adax
```

## Example:

```python
import adax


```

